summaryrefslogtreecommitdiffstats
path: root/src/input_common/drivers/joycon.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/input_common/drivers/joycon.h')
-rw-r--r--src/input_common/drivers/joycon.h5
1 files changed, 4 insertions, 1 deletions
diff --git a/src/input_common/drivers/joycon.h b/src/input_common/drivers/joycon.h
index 6d2e2ec78..316d383d8 100644
--- a/src/input_common/drivers/joycon.h
+++ b/src/input_common/drivers/joycon.h
@@ -88,9 +88,12 @@ private:
/// Returns a JoyconHandle corresponding to a PadIdentifier
std::shared_ptr<Joycon::JoyconDriver> GetHandle(PadIdentifier identifier) const;
/// Returns a PadIdentifier corresponding to the port number
PadIdentifier GetIdentifier(std::size_t port, Joycon::ControllerType type) const;
+ /// Returns a ParamPackage corresponding to the port number and joycon type
+ Common::ParamPackage GetParamPackage(std::size_t port, Joycon::ControllerType type) const;
+
std::string JoyconName(std::size_t port) const;
Common::Input::ButtonNames GetUIButtonName(const Common::ParamPackage& params) const;
@@ -88,9 +88,12 @@ private:
/// Returns a JoyconHandle corresponding to a PadIdentifier
std::shared_ptr<Joycon::JoyconDriver> GetHandle(PadIdentifier identifier) const;
- /// Returns a PadIdentifier corresponding to the port number
+ /// Returns a PadIdentifier corresponding to the port number and joycon type
PadIdentifier GetIdentifier(std::size_t port, Joycon::ControllerType type) const;